@@ -2,14 +2,16 @@
 #
 # This file is part of pyosmium. (https://osmcode.org/pyosmium/)
 #
-# Copyright (C) 2024 Sarah Hoffmann <lonvia@denofr.de> and others.
+# Copyright (C) 2025 Sarah Hoffmann <lonvia@denofr.de> and others.
 # For a full list of authors see the git log.
 import pytest
+import uuid
 
-import osmium as o
+import osmium
 
 from helpers import IDCollector
 
+
 def test_simple_way(test_data, tmp_path):
     ref_file = test_data('\n'.join((f"n{i} x2 y3" for i in range(10))))
 
@@ -17,13 +19,13 @@ def test_simple_way(test_data, tmp_path):
         id = 34
         nodes = [3, 6, 5]
 
-    outfile = str(tmp_path / 'test.osm')
+    outfile = str(tmp_path / f'{uuid.uuid4()}.osm')
 
-    with o.BackReferenceWriter(outfile, ref_file) as writer:
+    with osmium.BackReferenceWriter(outfile, ref_file) as writer:
         writer.add_way(TestWay())
 
     ids = IDCollector()
-    o.apply(outfile, ids)
+    osmium.apply(outfile, ids)
 
     assert ids.nodes == [3, 5, 6]
     assert ids.ways == [34]
@@ -32,10 +34,10 @@ def test_simple_way(test_data, tmp_path):
 
 def test_do_not_write_on_exception(test_data, tmp_path):
     ref_file = test_data('\n'.join((f"n{i} x2 y3" for i in range(10))))
-    outfile = tmp_path / 'test.osm'
+    outfile = tmp_path / f'{uuid.uuid4()}.osm'
 
     with pytest.raises(RuntimeError, match="inner error"):
-        with o.BackReferenceWriter(str(outfile), ref_file) as writer:
+        with osmium.BackReferenceWriter(str(outfile), ref_file):
             raise RuntimeError("inner error")
 
     assert not outfile.exists()
